import React, { useEffect, useState, useRef } from 'react';
import { LocaleProvider } from 'antd-mobile';
import styles from './index.css';
import { router, connect } from 'dva';
import { getToken, setToken } from '@/H5Public/utils/authority';
import requestJSON from '@/H5Public/utils/requestJSON';
import { setUserInfo } from '@/H5Public/utils/2022new/currentUser';
import config from '@/config/config';

const routerWhiteList = [
  '/login',
  '/webActivtiDetali',
  // 来访登记者填写表单
  '/visitorRegister/visitorFormPage',
];
const { Redirect } = router;

let BasicLayout = ({ children, dispatch, location: { pathname } }) => {
  if (pathname === '/login') {
    return <div>{children}</div>;
  }
  return <LocaleProvider locale={{
      value: '中国',
      label: '中国',
      language: undefined,
    }}>
    <div className={styles.normal}>
      {children}
    </div>
    </LocaleProvider>;
};
BasicLayout = connect()(BasicLayout);

function getUserInfo() {
  const url = config.mockServer + '/v1/api/uiaAdmin/userApi/getMyInfo'; // 获取用户基本信息
  requestJSON(url, {}).then((res) => {
    if (res && res.data) {
      setUserInfo(res.data);
    }
  });
}

export default (props) => {
  const { location: { pathname, query: { token, returnUrl } }, children } = props;
  useEffect(() => {
    if(token || getToken()){
      getUserInfo();
    }
  }, []);
  if (routerWhiteList.includes(pathname)) return children;
  if (!!token || getToken()) {
    if (!!token) {
      setToken(token);
    }
    if (!!returnUrl) {
      return <Redirect to={returnUrl} />;
    }
    return <BasicLayout {...props} />;
  }
  let loginPathname = '/login';
  if (!!returnUrl) {
    loginPathname = `${loginPathname}?returnUrl=${returnUrl}`;
  }
  return <Redirect to={loginPathname} />;
}

